@@ -5,7 +5,7 @@ import wda
 import random
 
 global img
-global point1, point2
+global point1, point2,devices
 
 def screen_shot(device_type,devices):
     if device_type == 'android':
@@ -77,18 +77,19 @@ def element_is_exist(devices,Prop,Value):
         b='=Value)'
         c=a+Prop+b
         d=eval(c)
-    return d
+    return str(d)
 
 def run_if(key,value):
-    key=str(key)
     z='.'
     y=z in value
+    y=str(y)
     if y=='True':
         x = value.split(".", 1)
         if key=='True':
             eval(x[1])
     else:
         if key=='True':
+            print(value)
             eval(value)
 
 def send_keys(devices,Prop,Value,msg):
@@ -112,9 +113,9 @@ def devices_connect(device_type,devices):
         u = wda.Client(devices)
     return  u
 
-# device=devices_connect('android',None)
-# a=element_is_exist('xpath','//*[@text="相机"]')
-# print(type(a))
-# print(a)
+devices=devices_connect('android',None)
+# a=element_is_exist(devices,'xpath','//*[@text="相机"]')
 # element_click('xpath','//*[@text="相机"]')
+# run_if(a,'wa.element_click(devices,"text","相机")')
+# eval('element_click(device,"text","相机")')
 # send_keys('xpath','//*[@resource-id="com.android.mms:id/embedded_text_editor"]','1777712')
\ No newline at end of file
